@@ -10,10 +10,12 @@
 #
 
 # expand archive
+mv julius-simple aaa
 rm -rf julius*
 tar xzvf $1
 ln -s julius-* julius
 rm -rf include/sent include/julius
+mv aaa julius-simple
 
 # update binaries
 cd julius
@@ -44,4 +46,5 @@ qkc -m doc/txt/*
 qkc -s -m doc/txt.ja/*
 
 # finished
-echo '#### FINISHED, you should remove julius* manually ###'
+rm -f julius
+echo '#### FINISHED, you should remove julius-ver directory manually ###'
